==> istio-model-v1beta1-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRedirectFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HTTPRedirectFluent<A extends HTTPRedirectFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildRedirectPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPRedirectRedirectPort getRedirectPort();
  public IsHTTPRedirectRedirectPort buildRedirectPort();
  public A withRedirectPort(IsHTTPRedirectRedirectPort redirectPort);
  public Boolean hasRedirectPort();
  public A withHTTPRedirectPort(HTTPRedirectPort hTTPRedirectPort);
  public HTTPRedirectFluent.HTTPRedirectPortNested<A> withNewHTTPRedirectPort();
  public HTTPRedirectFluent.HTTPRedirectPortNested<A> withNewHTTPRedirectPortLike(HTTPRedirectPort item);
  public A withNewHTTPRedirectPort(Integer port);
  public A withHTTPRedirectDerivePort(HTTPRedirectDerivePort hTTPRedirectDerivePort);
  public HTTPRedirectFluent.HTTPRedirectDerivePortNested<A> withNewHTTPRedirectDerivePort();
  public HTTPRedirectFluent.HTTPRedirectDerivePortNested<A> withNewHTTPRedirectDerivePortLike(HTTPRedirectDerivePort item);
  public String getAuthority();
  public A withAuthority(String authority);
  public Boolean hasAuthority();
  public Integer getRedirectCode();
  public A withRedirectCode(Integer redirectCode);
  public Boolean hasRedirectCode();
  public String getScheme();
  public A withScheme(String scheme);
  public Boolean hasScheme();
  public String getUri();
  public A withUri(String uri);
  public Boolean hasUri();
  public interface HTTPRedirectPortNested<N> extends Nested<N>,HTTPRedirectPortFluent<HTTPRedirectFluent.HTTPRedirectPortNested<N>>{
    public N and();
    public N endHTTPRedirectPort();
    
  }
  public interface HTTPRedirectDerivePortNested<N> extends Nested<N>,HTTPRedirectDerivePortFluent<HTTPRedirectFluent.HTTPRedirectDerivePortNested<N>>{
    public N and();
    public N endHTTPRedirectDerivePort();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRedirectFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HTTPRedirectFluent<A extends HTTPRedirectFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildRedirectPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPRedirectRedirectPort getRedirectPort();
  public IsHTTPRedirectRedirectPort buildRedirectPort();
  public A withRedirectPort(IsHTTPRedirectRedirectPort redirectPort);
  public Boolean hasRedirectPort();
  public A withHTTPRedirectPort(HTTPRedirectPort hTTPRedirectPort);
  public HTTPRedirectFluent.HTTPRedirectPortNested<A> withNewHTTPRedirectPort();
  public HTTPRedirectFluent.HTTPRedirectPortNested<A> withNewHTTPRedirectPortLike(HTTPRedirectPort item);
  public A withNewHTTPRedirectPort(Integer port);
  public A withHTTPRedirectDerivePort(HTTPRedirectDerivePort hTTPRedirectDerivePort);
  public HTTPRedirectFluent.HTTPRedirectDerivePortNested<A> withNewHTTPRedirectDerivePort();
  public HTTPRedirectFluent.HTTPRedirectDerivePortNested<A> withNewHTTPRedirectDerivePortLike(HTTPRedirectDerivePort item);
  public String getAuthority();
  public A withAuthority(String authority);
  public Boolean hasAuthority();
  public Integer getRedirectCode();
  public A withRedirectCode(Integer redirectCode);
  public Boolean hasRedirectCode();
  public String getScheme();
  public A withScheme(String scheme);
  public Boolean hasScheme();
  public String getUri();
  public A withUri(String uri);
  public Boolean hasUri();
  public interface HTTPRedirectPortNested<N> extends Nested<N>,HTTPRedirectPortFluent<HTTPRedirectFluent.HTTPRedirectPortNested<N>>{
    public N and();
    public N endHTTPRedirectPort();
    
  }
  public interface HTTPRedirectDerivePortNested<N> extends Nested<N>,HTTPRedirectDerivePortFluent<HTTPRedirectFluent.HTTPRedirectDerivePortNested<N>>{
    public N and();
    public N endHTTPRedirectDerivePort();
    
  }
  
}
